@@ -1,3 +1,12 @@
+"""
+Dataset argument classes for LLM compression workflows.
+
+This module defines dataclass-based argument containers for configuring dataset
+loading, preprocessing, and calibration parameters across different dataset
+sources and processing pipelines. Supports various input formats including
+HuggingFace datasets, custom JSON/CSV files, and DVC-managed datasets.
+"""
+
 from dataclasses import dataclass, field
 from typing import Any, Callable, Dict, List, Optional, Union
 
@@ -117,6 +126,16 @@ class DatasetArguments(CustomDatasetArguments):
         default=512,
         metadata={"help": "Number of samples to use for one-shot calibration"},
     )
+    calibrate_moe_context: bool = field(
+        default=False,
+        metadata={
+            "help": "If during calibration, the MoE context should be enabled "
+            "for the given model. This usually involves updating all MoE modules "
+            "in the model for the duration of calibration. See moe_context under "
+            "modeling/prepare.py for a list of supported MoEs and their updated "
+            "module definitions"
+        },
+    )
     shuffle_calibration_samples: Optional[bool] = field(
         default=True,
         metadata={
@@ -162,15 +181,6 @@ class DatasetArguments(CustomDatasetArguments):
             ),
         },
     )
-    trust_remote_code_data: bool = field(
-        default=False,
-        metadata={
-            "help": "Whether or not to allow for datasets defined on the Hub using "
-            "a dataset script. This option should only be set to True for "
-            "repositories you trust and in which you have read the code, as it "
-            "will execute code present on the Hub on your local machine."
-        },
-    )
     # --- pipeline arguments --- #
     pipeline: Optional[str] = field(
         default="independent",
@@ -181,7 +191,18 @@ class DatasetArguments(CustomDatasetArguments):
         },
     )
     tracing_ignore: List[str] = field(
-        default_factory=lambda: ["_update_causal_mask"],
+        default_factory=lambda: [
+            "_update_causal_mask",
+            "create_causal_mask",
+            "make_causal_mask",
+            "get_causal_mask",
+            "mask_interface",
+            "mask_function",
+            "_prepare_4d_causal_attention_mask",
+            "_prepare_fsmt_decoder_inputs",
+            "_prepare_4d_causal_attention_mask_with_cache_position",
+            "_update_linear_attn_mask",
+        ],
         metadata={
             "help": "List of functions to ignore during tracing, either "
             "{module}.{method_name} or {function_name}"
@@ -197,3 +218,15 @@ class DatasetArguments(CustomDatasetArguments):
             "definition"
         },
     )
+    quantization_aware_calibration: bool = field(
+        default=True,
+        metadata={
+            "help": "Whether to enable quantization-aware calibration in the pipeline. "
+            "When True, quantization is applied during forward pass in calibration. "
+            "When False, quantization is disabled during forward pass in calibration. "
+            "Default is set to True."
+        },
+    )
+
+    def is_dataset_provided(self) -> bool:
+        return self.dataset is not None or self.dataset_path is not None
