@@ -1,3 +1,11 @@
+"""
+Compression session management for LLM compression workflows.
+
+Provides the main CompressionSession class for managing compression
+workflows, including lifecycle management, event handling, callback
+registration, and state tracking.
+"""
+
 from dataclasses import dataclass
 from typing import Any, Callable, Dict, List, Optional, Union
 
@@ -220,17 +228,6 @@ class CompressionSession:
 
         logger.warning("Recipe not found in session - it may have been reset")
 
-    def get_modifiers(self):
-        """
-        Get all modifiers across all stages
-        """
-        stage_modifiers = self.lifecycle.modifiers
-        return [
-            modifier
-            for stage_modifier in stage_modifiers
-            for modifier in stage_modifier.modifiers
-        ]  # noqa: E127
-
     def _log_model_info(self):
         # Log model level logs if cadence reached
         current_index = self._lifecycle.global_step
