@@ -2,15 +2,16 @@ import contextlib
 import inspect
 from collections import deque
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Set, Tuple
 
 import torch
-from compressed_tensors.quantization import find_name_or_class_matches
+from accelerate.hooks import remove_hook_from_module
 from compressed_tensors.utils import (
     has_offloaded_params,
     offloaded_dispatch,
     remove_dispatch,
 )
+from compressed_tensors.utils.match import match_targets
 from loguru import logger
 from torch.fx import Graph, GraphModule, Node
 from torch.fx.graph import PythonCode
@@ -73,9 +74,7 @@ class Subgraph:
         except Exception as exception:
             raise RuntimeError(
                 "Raised an exception during execution of the following code:\n"
-                f"```\n{add_line_numbers(self._code.src)}\n```\n"
-                "This is likely due to a violation of shape assumptions made when "
-                "tracing"
+                f"```\n{add_line_numbers(self._code.src)}\n```"
             ) from exception
 
         return outputs
@@ -169,19 +168,20 @@ class SequentialTracer(HFTracer):
     """
 
     def __init__(self, ancestors: Set[Module], offloaded: Set[Module]):
-        super().__init__()
         self.ancestors = ancestors
         self.offloaded = offloaded
 
+        # skip any mask creation functions not already caught by the autowrapper
+        super().__init__(autowrap_functions=_get_autowrap_functions())
+
         # check unlikely case that ancestors have direct params which are offloaded
         offloaded_ancestors = offloaded & ancestors
-        if offloaded_ancestors:
-            names = set(module.__class__.__name__ for module in offloaded_ancestors)
+        for ancestor in offloaded_ancestors:
+            remove_hook_from_module(ancestor, recurse=False)
+            self.offloaded.remove(ancestor)
             logger.warning(
-                "The following modules are call graph ancestors of sequential targets,"
-                f"but also contain offloaded modules: {names}.\n"
-                "These modules will not be traced, and any sequential target children "
-                "will be executed jointly, which may lead to OOM errors"
+                f"Direct parameters attached to {ancestor.__class__.__name__} have "
+                "been onloaded in order to ensure safe graph capture and execution"
             )
 
     def create_arg(self, a: Any) -> Argument:
@@ -303,10 +303,12 @@ def topological_partition(graph: GraphModule, targets: Set[Module]) -> List[List
                 if user in partitions[index]:
                     user_partitions.append(index)
                     break
-        partition_index = min(user_partitions)
-        partitions[partition_index].insert(0, node)
 
-    assert set().union(*partitions) == set(graph.graph.nodes)
+        # workaround
+        if len(user_partitions):
+            partition_index = min(user_partitions)
+            partitions[partition_index].insert(0, node)
+
     return partitions
 
 
@@ -424,7 +426,7 @@ def match_modules(model: Module, target_names: List[str]) -> Set[Module]:
     return set(
         module
         for name, module in model.named_modules()
-        if find_name_or_class_matches(name, module, target_names)
+        if match_targets(name, module, target_names)
     )
 
 
@@ -517,8 +519,8 @@ def get_sequential_ancestors(model: Module, targets: Set[Module]) -> Set[Module]
 def dispatch_for_sequential(model: PreTrainedModel) -> PreTrainedModel:
     """
     Dispatch a model for sequential calibration using a sequential pipeline.
-    The model will be offloaded to the CPU and dispatched to CUDA device if available.
-    Removes any existing hooks.
+    The model will be offloaded to the CPU and dispatched to CUDA/XPU device
+    if available. Removes any existing hooks.
 
     :param model: model to dispatch
     :return: dispatched model
@@ -527,7 +529,18 @@ def dispatch_for_sequential(model: PreTrainedModel) -> PreTrainedModel:
 
     if torch.cuda.is_available():
         offloaded_dispatch(model, execution_device=torch.device("cuda:0"))
+    elif hasattr(torch, "xpu") and torch.xpu.is_available():
+        offloaded_dispatch(model, execution_device=torch.device("xpu:0"))
     else:
-        logger.warning("CUDA is not available! Compressing model on CPU instead")
+        logger.warning("CUDA/XPU is not available! Compressing model on CPU instead")
 
     return model
+
+
+def _get_autowrap_functions() -> Tuple[Callable[[Any], Any], ...]:
+    try:
+        from transformers.masking_utils import LAYER_PATTERN_TO_MASK_FUNCTION_MAPPING
+
+        return tuple(LAYER_PATTERN_TO_MASK_FUNCTION_MAPPING.values())
+    except ImportError:
+        return tuple()
