@@ -2,43 +2,101 @@ import dataclasses
 import enum
 import logging
 import os
-import unittest
+from dataclasses import dataclass
+from enum import Enum
 from pathlib import Path
 from subprocess import PIPE, STDOUT, run
-from typing import List, Optional, Union
+from typing import Callable, List, Optional, Union
 
+import pytest
+import torch
 import yaml
 from datasets import Dataset
 from transformers import ProcessorMixin
 
-from tests.data import CustomTestConfig, TestConfig
+TEST_DATA_FILE = os.environ.get("TEST_DATA_FILE", None)
 
 
-# TODO: probably makes sense to move this type of function to a more central place,
-# which can be used by __init__.py as well
-def is_torch_available():
+# TODO: maybe test type as decorators?
+class TestType(Enum):
+    SANITY = "sanity"
+    REGRESSION = "regression"
+    SMOKE = "smoke"
+
+
+class Cadence(Enum):
+    COMMIT = "commit"
+    WEEKLY = "weekly"
+    NIGHTLY = "nightly"
+
+
+@dataclass
+class TestConfig:
+    test_type: TestType
+    cadence: Cadence
+
+
+def _enough_gpus(num_required_gpus):
     try:
         import torch  # noqa: F401
 
-        return True
+        return torch.cuda.device_count() >= num_required_gpus
     except ImportError:
         return False
 
 
-def is_gpu_available():
+def requires_gpu(test_case_or_num):
     """
-    Check for GPU and warn if not found
+    Pytest decorator to skip based on number of available GPUs.
+
+    Designed for backwards compatibility with the old requires_gpu decorator
+    Usage:
+    @requires_gpu
+    def test_something():
+        # only runs if there is at least 1 GPU available
+        pass
+
+    @requires_gpu(2)
+    def test_something_else():
+        # only runs if there are at least 2 GPUs available
+        pass
     """
-    try:
-        import torch  # noqa: F401
+    if isinstance(test_case_or_num, int):
+        num_required_gpus = test_case_or_num
+    else:
+        num_required_gpus = 1
 
-        return torch.cuda.device_count() > 0
-    except ImportError:
-        return False
+    decorator = pytest.mark.skipif(
+        not _enough_gpus(num_required_gpus),
+        reason=f"Not enough GPUs available, {num_required_gpus} GPUs required",
+    )
+    if isinstance(test_case_or_num, int):
+        return decorator
+    else:
+        return decorator(test_case_or_num)
 
 
-def requires_gpu(test_case):
-    return unittest.skipUnless(is_gpu_available(), "test requires GPU")(test_case)
+def requires_gpu_mem(required_amount: Union[int, float]) -> pytest.MarkDecorator:
+    """
+    Pytest decorator to skip based on total available GPU memory (across all GPUs). This
+    plays nicely with the CUDA_VISIBLE_DEVICES environment variable.
+
+    Note: make sure to account for measured memory vs. simple specs. For example, H100
+    has '80 GiB' VRAM, however, the actual number, at least per PyTorch, is ~79.2 GiB.
+
+    :param amount: amount of required GPU memory in GiB
+    """
+
+    vram_bytes = sum(
+        torch.cuda.mem_get_info(device_id)[1]
+        for device_id in range(torch.cuda.device_count())
+    )
+    actual_vram = vram_bytes / 1024**3
+    reason = (
+        f"{required_amount} GiB GPU memory required, "
+        f"{actual_vram:.1f} GiB GPU memory found"
+    )
+    return pytest.mark.skipif(required_amount > actual_vram, reason=reason)
 
 
 def _load_yaml(config_path: str):
@@ -64,9 +122,7 @@ def _validate_test_config(config: dict):
 
 # Set cadence in the config. The environment must set if nightly, weekly or commit
 # tests are running
-def parse_params(
-    configs_directory: Union[list, str], type: Optional[str] = None
-) -> List[Union[dict, CustomTestConfig]]:
+def parse_params(configs_directory: Union[list, str]) -> List[dict]:
     # parses the config files provided
 
     config_dicts = []
@@ -78,6 +134,10 @@ def parse_params(
 
         for file in os.listdir(current_config_dir):
             config_path = os.path.join(current_config_dir, file)
+            if TEST_DATA_FILE is not None:
+                if not config_path.endswith(TEST_DATA_FILE):
+                    continue
+
             config = _load_yaml(config_path)
             if not config:
                 continue
@@ -90,15 +150,12 @@ def parse_params(
             if not isinstance(expected_cadence, list):
                 expected_cadence = [expected_cadence]
             if cadence in expected_cadence:
-                if type == "custom":
-                    config = CustomTestConfig(**config)
-                else:
-                    if not _validate_test_config(config):
-                        raise ValueError(
-                            "The config provided does not comply with the expected "
-                            "structure. See tests.data.TestConfig for the expected "
-                            "fields."
-                        )
+                if not _validate_test_config(config):
+                    raise ValueError(
+                        "The config provided does not comply with the expected "
+                        "structure. See tests.data.TestConfig for the expected "
+                        "fields."
+                    )
                 config_dicts.append(config)
             else:
                 logging.info(
@@ -228,21 +285,18 @@ def process_dataset(
                 "images": sample["image"],
             }
 
-    elif ds_name == "pile-val-backup":
-
-        def preprocess(example):
-            return {
-                "input_ids": processor.encode(example["text"].strip())[:max_seq_length]
-            }
-
-        ds = ds.map(preprocess, remove_columns=ds.column_names)
-        # Note: potentially swap filtering to pad for AWQ
-        ds = ds.filter(lambda example: len(example["input_ids"]) >= max_seq_length)
-        return ds
-
     else:
         raise NotImplementedError(f"Cannot preprocess dataset {ds.info.dataset_name}")
 
     ds = ds.map(process, remove_columns=ds.column_names)
 
     return ds
+
+
+def requires_cadence(cadence: Union[str, List[str]]) -> Callable:
+    cadence = [cadence] if isinstance(cadence, str) else cadence
+    current_cadence = os.environ.get("CADENCE", "commit")
+
+    return pytest.mark.skipif(
+        (current_cadence not in cadence), reason="cadence mismatch"
+    )
